PcmBlock

Struct PcmBlock 

pub struct PcmBlock<'a> {
    pub format: PcmFormat,
    pub timestamp: Micros,
    pub data: &'a [u8],
}
A borrowed block of interleaved PCM.

Fields

format: PcmFormat

Rate, channels, encoding.

timestamp: Micros

Capture instant of the first frame on the device’s monotonic clock.

data: &'a [u8]

Interleaved sample bytes; a whole number of frames.

Implementations

Source

impl<'a> PcmBlock<'a>

pub fn new( format: PcmFormat, timestamp: Micros, data: &'a [u8], ) -> Result<PcmBlock<'a>, Error>

A block over data, which must be non-empty and frame-aligned.

pub fn frames(&self) -> usize

Sample frames in this block.

pub fn duration_micros(&self) -> u64

Duration of this block in microseconds.

pub fn end(&self) -> Micros

Timestamp of the frame that would follow this block.

pub fn samples_i16(&self) -> Option<impl Iterator<Item = i16> + 'a>

Iterate the samples of an SampleFormat::I16 block, interleaved. Returns None for any other encoding.